const std = @import("std");
const stdout = std.io.getStdOut().writer();

const Base64 = @import("base64.zig");

const usageText =
    \\Usage: baze64 {-d/-D} {-h/-H} input
    \\With no arguments, encodes input into a base64 string
    \\Args:
    \\  -d -D: decodes a base64 string
    \\  -h -H: print this help
    ;


pub fn main() !void {
    var gpa = std.heap.GeneralPurposeAllocator(.{}).init;
    const allocator = gpa.allocator();
    var args = try std.process.argsWithAllocator(allocator);
    defer args.deinit();

    var decodeSwitch = false;
    var input: []const u8 = undefined;

    // Skip arg[0]
    _ = args.skip();

    while (true) {
        const argVal = args.next();
        var arg: []const u8 = undefined;
        if (argVal) |a| {
            arg = a;
        } else {
            break;
        }

        if (std.mem.eql(u8, arg, "-d") or std.mem.eql(u8, arg, "-D")) {
            decodeSwitch = true;
        } else if (std.mem.eql(u8, arg, "-h") or std.mem.eql(u8, arg, "-H")) {
            try stdout.print("{s}\n", .{usageText});
            std.process.exit(0);
        } else {
            input = arg;
            break;
        }
    }

    if (decodeSwitch) {
        const decoded = try Base64.decode(allocator, input);
        try stdout.print("{s}", .{decoded});
    } else {
        const encoded = try Base64.encode(allocator, input);
        try stdout.print("{s}", .{encoded});
    }
}
